@@ -1,4 +1,3 @@
-import numpy as np
 from examples.example_imports import *
 from manim_express import *
 
@@ -97,11 +96,12 @@ class Bezier(EagerModeScene):
         self.hold_on()
 
 
-CONFIG.preview = False
-# CONFIG.full_screen = True
+CONFIG.preview = True
+CONFIG.full_screen = True
+# CONFIG.use_online_tex=True
 # CONFIG.gif = True
 # CONFIG.color = WHITE
 bezier = Bezier()
-bezier.clip1()
+# bezier.clip1()
 # bezier.render()
-# bezier.clip2()
+bezier.clip2()
